@@ -1,5 +1,6 @@
-/* 
- * Copyright (C) 2004-2006 Jean-Yves Lefort <jylefort@brutele.be>
+/*
+ * Mail Notification
+ * Copyright (C) 2003-2007 Jean-Yves Lefort <jylefort@brutele.be>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -11,9 +12,9 @@
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  * GNU General Public License for more details.
  *
- * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+ * You should have received a copy of the GNU General Public License along
+ * with this program; if not, write to the Free Software Foundation, Inc.,
+ * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
  */
 
 #ifndef _MN_CLIENT_SESSION_H
@@ -174,8 +175,8 @@ typedef struct
 #endif /* WITH_SASL */
 } MNClientSessionCallbacks;
 
-gboolean mn_client_session_run (MNClientSessionState *states,
-				MNClientSessionCallbacks *callbacks,
+gboolean mn_client_session_run (const MNClientSessionState *states,
+				const MNClientSessionCallbacks *callbacks,
 #if WITH_SSL
 				gboolean use_ssl,
 #endif
