@@ -81,6 +81,8 @@
   MN_CONF_POPUPS_EXPIRATION_DELAY_NAMESPACE "/minutes"
 #define MN_CONF_POPUPS_EXPIRATION_DELAY_SECONDS \
   MN_CONF_POPUPS_EXPIRATION_DELAY_NAMESPACE "/seconds"
+#define MN_CONF_POPUPS_ACTIONS \
+  MN_CONF_POPUPS_NAMESPACE "/actions"
 
 /* obsolete keys */
 #define MN_CONF_OBSOLETE_MAILBOXES \
