@@ -23,10 +23,12 @@
 #include <libgnomevfs/gnome-vfs.h>
 #include "mn-message-mime.h"
 #include "mn-gmime-stream-vfs.h"
+#include "mn-util.h"
 
 /*** functions ***************************************************************/
 
 static char *mn_message_mime_header_decode_text (const char *str);
+static gboolean mn_message_mime_is_spam (GMimeMessage *mime_message);
 
 /*** implementation **********************************************************/
 
@@ -52,6 +54,26 @@ mn_message_mime_header_decode_text (const char *str)
     }
 }
 
+static gboolean
+mn_message_mime_is_spam (GMimeMessage *mime_message)
+{
+  const char *spam;
+
+  g_return_val_if_fail(GMIME_IS_MESSAGE(mime_message), FALSE);
+
+  /* SpamAssassin */
+  spam = g_mime_message_get_header(mime_message, "X-Spam-Status");
+  if (spam && mn_ascii_str_case_has_prefix(spam, "yes"))
+    return TRUE;
+
+  /* bogofilter */
+  spam = g_mime_message_get_header(mime_message, "X-Bogosity");
+  if (spam && mn_ascii_str_case_has_prefix(spam, "yes"))
+    return TRUE;
+
+  return FALSE;
+}
+
 MNMessage *
 mn_message_new_from_mime_message (MNMailbox *mailbox,
 				  GMimeMessage *mime_message,
@@ -87,6 +109,9 @@ mn_message_new_from_mime_message_full (GType type,
   g_return_val_if_fail(mailbox == NULL || MN_IS_MAILBOX(mailbox), NULL);
   g_return_val_if_fail(GMIME_IS_MESSAGE(mime_message), NULL);
 
+  if (mn_message_mime_is_spam(mime_message))
+    return NULL;
+
   if (handle_status)
     {
       const char *status;
@@ -219,7 +244,7 @@ mn_message_new_from_uri_full (GType type,
 	  if (result == GNOME_VFS_OK)
 	    return message;
 	  else
-	    g_object_unref(message);
+	    mn_g_object_null_unref(message); /* message can be null */
 	}
       else
 	gnome_vfs_close(handle);
